function [sedfitparameters] = mlSEDFIT_DefineDataModel(autofindmeniscus)

sedfitparameters.AutoRun = 0;
sedfitparameters.AutoFit = 0;
sedfitparameters.AutoSubtractSystematicNoise = 1;
sedfitparameters.DataDirectory = 'c:\sedfit\ExampleData'; 
sedfitparameters.Channel = 'RA3';
sedfitparameters.FirstScan = 1;
sedfitparameters.LastScan = 100;
sedfitparameters.ScanInterval = 1;

sedfitparameters.Meniscus = 6.18; 
sedfitparameters.MeniscusLowerLimit = sedfitparameters.Meniscus - 0.03; 
sedfitparameters.MeniscusUpperLimit = sedfitparameters.Meniscus + 0.03; 
sedfitparameters.MeniscusFitted = 1;
sedfitparameters.Bottom = 7.2;
sedfitparameters.BottomLowerLimit = sedfitparameters.Bottom - 0.03; 
sedfitparameters.BottomUpperLimit = sedfitparameters.Bottom + 0.03; 
sedfitparameters.BottomFitted = 0;
sedfitparameters.LeftFitLimit = 6.25;
sedfitparameters.RightFitLimit = 7.1; 

sedfitparameters.Model = 'cofs';
sedfitparameters.RegularizationType = 'maxent';
sedfitparameters.RegularizationPvalue = 0.683;
sedfitparameters.StartingFrictionalRatio = 1.4;
sedfitparameters.FrictionalRatioFitted = 1;

sedfitparameters.BaselineFitted = 1; 
sedfitparameters.RINoiseFitted = 1;  
sedfitparameters.TINoiseFitted = 1;
sedfitparameters.Resolution = 200; 
sedfitparameters.Smin = 1;
sedfitparameters.Smax = 50;
sedfitparameters.GridfromFile = 0;
sedfitparameters.UseLogSpaceSgrid = 0;

sedfitparameters.Vbar = 0.73;
sedfitparameters.BufferDensity = 1.00000;
sedfitparameters.BufferViscosity = 0.01012;
sedfitparameters.SupressBaselineCorrelation = 1;

sedfitparameters.FittinAlgorithm = 'Levenberg-Marquardt'; 
sedfitparameters.NumberComputationThreads = 4; 
sedfitparameters.FilterDataSpikes = 1; 
sedfitparameters.DataSpikeThreshold = 0.4;
sedfitparameters.ShowResidualsHistogram = 0;

%% a very simple meniscus finder for absorbance data: 
%1) assume a very rough range from 5.8 to 6.5
%2) read last scan, assuming depletion has happened 
%3) read radius value where signal is maximum, from the meniscus spike
withplot = 1;
if autofindmeniscus,
    findmenmin = 5.8; findmenmax = 6.5;
    lastname = sprintf('%05d.%s',sedfitparameters.LastScan,sedfitparameters.Channel);
    lastscanpath = [sedfitparameters.DataDirectory '\' lastname];
    fid = fopen(lastscanpath,'rt');
    line= fgets(fid); line = fgets(fid);
    scandata = fscanf(fid,'%g %g %g',[3 inf]);scandata = scandata'; 
    fclose(fid);
    maxind = sum(scandata(:,1) <= findmenmax);
    [spike,ispike] = max(scandata(1:maxind,2));
    spikeradius = scandata(ispike,1);
    if withplot,
        figure(1); clf; hold on;
        plot(scandata(:,1),scandata(:,2),'k-');
        plot(spikeradius*[1 1],[min(scandata(:,2)) max(scandata(:,2))],'r-');
%         prompt = sprintf('meniscus estimated at %f - press ENTER to accept or change value',spikeradius);
        ans = inputdlg('meniscus estimation - press ENTER or change value','meniscus',1,{num2str(spikeradius)});
        if length(ans) > 0, 
            spikeradius = str2num(ans{1});
        end;
    end;
    sedfitparameters.Meniscus = spikeradius;
end;