function [peaks] = mlSEDFIT_IntegrateDistribution(distribution,ranges)

dists = distribution(:,1); distc = distribution(:,2); ndist = length(dists);

figure(2); clf; hold on;
plot(dists,distc,'k-');
box on;
xlabel('sedimentation coefficient (S)');
ylabel('c(s) or ls-g*(s) (signal/S)');

peaks.totalsignal = trapz(dists,distc);
fprintf('\ntotal signal = %f\n',peaks.totalsignal);

if 0 == length(ranges),
    npeaks = 1;
    bintegrating = 1;
    while bintegrating,
        title(['click on peak #' num2str(npeaks) ' to be integrated (or outside the graph to stop)']);
        [x,y] = ginput(1);
        if x < min(dists) || x > max(dists),
            bintegrating = 0;
            npeaks = npeaks - 1;
            title('');
        else
            ipeak = sum(dists < x);
            cpeak = distc(ipeak);
            imin = ipeak-1;
            while imin > 0 & distc(imin) > 0.9*cpeak,
                imin = imin - 1;
                if distc(imin) > distc(imin+1), break; end;
            end;
            while imin > 1 & distc(imin-1) < distc(imin), imin = imin - 1; end;
            imax = ipeak + 1;
            while imax < ndist & distc(imax) > 0.9*cpeak,
                imax = imax + 1;
                if distc(imax) > distc(imax-1), break;end;
            end;
            while imax < ndist-1 & distc(imax+1) < distc(imax), imax = imax + 1; end;
            peaks.signal(npeaks) = trapz(dists(imin:imax),distc(imin:imax));
            peaks.sw(npeaks) = sum(distc(imin:imax).*dists(imin:imax))/sum(distc(imin:imax));
            peaks.smin(npeaks) = dists(imin);
            peaks.smax(npeaks) = dists(imax);
            patch([dists(imin); dists(imin:imax); dists(imax)],[0; distc(imin:imax); 0],'m','EdgeColor','none','FaceAlpha',0.6);
            fprintf('peak #%d (%.2fS-%.2fS): sw = %.3f, signal = %.4f (%.3f%% of total %.3f)\n',npeaks,peaks.smin(npeaks),peaks.smax(npeaks),peaks.sw(npeaks),peaks.signal(npeaks),100*peaks.signal(npeaks)/peaks.totalsignal,peaks.totalsignal);
            swtext = sprintf('s_w = %.3fS (%.2f%%)',peaks.sw(npeaks),100*peaks.signal(npeaks)/peaks.totalsignal);
            %         swtext = sprintf('s_w = %.3fS (%.2f)',peaks.sw(npeaks));
            text(peaks.sw(npeaks),max(distc(imin:imax)),swtext,'FontSize',8);
            npeaks = npeaks + 1;
        end;
    end;
else
    [npeaks, ~] = size(ranges);
    for p=1:npeaks,
        imin = sum(dists < ranges(p,1));
        imax = sum(dists <= ranges(p,2));
        peaks.signal(p) = trapz(dists(imin:imax),distc(imin:imax));
        peaks.sw(p) = sum(distc(imin:imax).*dists(imin:imax))/sum(distc(imin:imax));
        peaks.smin(p) = dists(imin);
        peaks.smax(p) = dists(imax);
        patch([dists(imin); dists(imin:imax); dists(imax)],[0; distc(imin:imax); 0],'m','EdgeColor','none','FaceAlpha',0.6);
        fprintf('peak #%d (%.2fS-%.2fS): sw = %.3f, signal = %.4f (%.3f%% of total %.3f)\n',npeaks,peaks.smin(p),peaks.smax(p),peaks.sw(p),peaks.signal(p),100*peaks.signal(p)/peaks.totalsignal,peaks.totalsignal);
        swtext = sprintf('s_w = %.3fS (%.2f%%)',peaks.sw(p),100*peaks.signal(p)/peaks.totalsignal);
        %         swtext = sprintf('s_w = %.3fS (%.2f)',peaks.sw(npeaks));
        text(peaks.sw(p),max(distc(imin:imax)),swtext,'FontSize',8);
    end;
end;

